@@ -418,8 +418,6 @@ class MAPIUtils {
         if (isset($supportmask[PR_STORE_SUPPORT_MASK]) && ($supportmask[PR_STORE_SUPPORT_MASK] & STORE_UNICODE_OK)) {
             ZLog::Write(LOGLEVEL_DEBUG, "Store supports properties containing Unicode characters.");
             define('STORE_SUPPORTS_UNICODE', true);
-            //setlocale to UTF-8 in order to support properties containing Unicode characters
-            setlocale(LC_CTYPE, "en_US.UTF-8");
             define('STORE_INTERNET_CPID', INTERNET_CPID_UTF8);
         }
     }
@@ -482,6 +480,145 @@ class MAPIUtils {
         );
     }
 
+    /**
+     * Calculates the native body type of a message using available properties. Refer to oxbbody.
+     *
+     * @param array             $messageprops
+     *
+     * @access public
+     * @return int
+     */
+    public static function GetNativeBodyType($messageprops) {
+        //check if the properties are set and get the error code if needed
+        if (!isset($messageprops[PR_BODY]))             $messageprops[PR_BODY]              = self::getError(PR_BODY, $messageprops);
+        if (!isset($messageprops[PR_RTF_COMPRESSED]))   $messageprops[PR_RTF_COMPRESSED]    = self::getError(PR_RTF_COMPRESSED, $messageprops);
+        if (!isset($messageprops[PR_HTML]))             $messageprops[PR_HTML]              = self::getError(PR_HTML, $messageprops);
+        if (!isset($messageprops[PR_RTF_IN_SYNC]))      $messageprops[PR_RTF_IN_SYNC]       = self::getError(PR_RTF_IN_SYNC, $messageprops);
+
+        if ( // 1
+                ($messageprops[PR_BODY]             == MAPI_E_NOT_FOUND) &&
+                ($messageprops[PR_RTF_COMPRESSED]   == MAPI_E_NOT_FOUND) &&
+                ($messageprops[PR_HTML]             == MAPI_E_NOT_FOUND))
+                    return SYNC_BODYPREFERENCE_PLAIN;
+                elseif ( // 2
+                        ($messageprops[PR_BODY]             == MAPI_E_NOT_ENOUGH_MEMORY) &&
+                        ($messageprops[PR_RTF_COMPRESSED]   == MAPI_E_NOT_FOUND) &&
+                        ($messageprops[PR_HTML]             == MAPI_E_NOT_FOUND))
+                        return SYNC_BODYPREFERENCE_PLAIN;
+                elseif ( // 3
+                        ($messageprops[PR_BODY]             == MAPI_E_NOT_ENOUGH_MEMORY) &&
+                        ($messageprops[PR_RTF_COMPRESSED]   == MAPI_E_NOT_ENOUGH_MEMORY) &&
+                        ($messageprops[PR_HTML]             == MAPI_E_NOT_FOUND))
+                        return SYNC_BODYPREFERENCE_RTF;
+                elseif ( // 4
+                        ($messageprops[PR_BODY]             == MAPI_E_NOT_ENOUGH_MEMORY) &&
+                        ($messageprops[PR_RTF_COMPRESSED]   == MAPI_E_NOT_ENOUGH_MEMORY) &&
+                        ($messageprops[PR_HTML]             == MAPI_E_NOT_ENOUGH_MEMORY) &&
+                        ($messageprops[PR_RTF_IN_SYNC]))
+                        return SYNC_BODYPREFERENCE_RTF;
+                elseif ( // 5
+                        ($messageprops[PR_BODY]             == MAPI_E_NOT_ENOUGH_MEMORY) &&
+                        ($messageprops[PR_RTF_COMPRESSED]   == MAPI_E_NOT_ENOUGH_MEMORY) &&
+                        ($messageprops[PR_HTML]             == MAPI_E_NOT_ENOUGH_MEMORY) &&
+                        (!$messageprops[PR_RTF_IN_SYNC]))
+                        return SYNC_BODYPREFERENCE_HTML;
+                elseif ( // 6
+                        ($messageprops[PR_RTF_COMPRESSED]   != MAPI_E_NOT_FOUND   || $messageprops[PR_RTF_COMPRESSED]  == MAPI_E_NOT_ENOUGH_MEMORY) &&
+                        ($messageprops[PR_HTML]             != MAPI_E_NOT_FOUND   || $messageprops[PR_HTML]            == MAPI_E_NOT_ENOUGH_MEMORY) &&
+                        ($messageprops[PR_RTF_IN_SYNC]))
+                        return SYNC_BODYPREFERENCE_RTF;
+                elseif ( // 7
+                        ($messageprops[PR_RTF_COMPRESSED]   != MAPI_E_NOT_FOUND   || $messageprops[PR_RTF_COMPRESSED]  == MAPI_E_NOT_ENOUGH_MEMORY) &&
+                        ($messageprops[PR_HTML]             != MAPI_E_NOT_FOUND   || $messageprops[PR_HTML]            == MAPI_E_NOT_ENOUGH_MEMORY) &&
+                        (!$messageprops[PR_RTF_IN_SYNC]))
+                        return SYNC_BODYPREFERENCE_HTML;
+                elseif ( // 8
+                        ($messageprops[PR_BODY]             != MAPI_E_NOT_FOUND   || $messageprops[PR_BODY]            == MAPI_E_NOT_ENOUGH_MEMORY) &&
+                        ($messageprops[PR_RTF_COMPRESSED]   != MAPI_E_NOT_FOUND   || $messageprops[PR_RTF_COMPRESSED]  == MAPI_E_NOT_ENOUGH_MEMORY) &&
+                        ($messageprops[PR_RTF_IN_SYNC]))
+                        return SYNC_BODYPREFERENCE_RTF;
+                elseif ( // 9.1
+                        ($messageprops[PR_BODY]             != MAPI_E_NOT_FOUND   || $messageprops[PR_BODY]            == MAPI_E_NOT_ENOUGH_MEMORY) &&
+                        ($messageprops[PR_RTF_COMPRESSED]   != MAPI_E_NOT_FOUND   || $messageprops[PR_RTF_COMPRESSED]  == MAPI_E_NOT_ENOUGH_MEMORY) &&
+                        (!$messageprops[PR_RTF_IN_SYNC]))
+                        return SYNC_BODYPREFERENCE_PLAIN;
+                elseif ( // 9.2
+                        ($messageprops[PR_RTF_COMPRESSED]   != MAPI_E_NOT_FOUND   || $messageprops[PR_RTF_COMPRESSED]  == MAPI_E_NOT_ENOUGH_MEMORY) &&
+                        ($messageprops[PR_BODY]             == MAPI_E_NOT_FOUND) &&
+                        ($messageprops[PR_HTML]             == MAPI_E_NOT_FOUND))
+                        return SYNC_BODYPREFERENCE_RTF;
+                elseif ( // 9.3
+                        ($messageprops[PR_BODY]             != MAPI_E_NOT_FOUND   || $messageprops[PR_BODY]            == MAPI_E_NOT_ENOUGH_MEMORY) &&
+                        ($messageprops[PR_RTF_COMPRESSED]   == MAPI_E_NOT_FOUND) &&
+                        ($messageprops[PR_HTML]             == MAPI_E_NOT_FOUND))
+                        return SYNC_BODYPREFERENCE_PLAIN;
+                elseif ( // 9.4
+                        ($messageprops[PR_HTML]             != MAPI_E_NOT_FOUND   || $messageprops[PR_HTML]            == MAPI_E_NOT_ENOUGH_MEMORY) &&
+                        ($messageprops[PR_BODY]             == MAPI_E_NOT_FOUND) &&
+                        ($messageprops[PR_RTF_COMPRESSED]   == MAPI_E_NOT_FOUND))
+                        return SYNC_BODYPREFERENCE_HTML;
+                else // 10
+                    return SYNC_BODYPREFERENCE_PLAIN;
+    }
+
+    /**
+     * Returns the error code for a given property. Helper for getNativeBodyType function.
+     *
+     * @param int               $tag
+     * @param array             $messageprops
+     *
+     * @access private
+     * @return int (MAPI_ERROR_CODE)
+     */
+    private static function getError($tag, $messageprops) {
+        $prBodyError = mapi_prop_tag(PT_ERROR, mapi_prop_id($tag));
+        if(isset($messageprops[$prBodyError]) && mapi_is_error($messageprops[$prBodyError])) {
+            if($messageprops[$prBodyError] == MAPI_E_NOT_ENOUGH_MEMORY_32BIT ||
+                    $messageprops[$prBodyError] == MAPI_E_NOT_ENOUGH_MEMORY_64BIT) {
+                        return MAPI_E_NOT_ENOUGH_MEMORY;
+                    }
+        }
+        return MAPI_E_NOT_FOUND;
+    }
+
+
+    /**
+     * Function will be used to decode smime messages and convert it to normal messages.
+     *
+     * @param MAPISession       $session
+     * @param MAPIStore         $store
+     * @param MAPIAdressBook    $addressBook
+     * @param MAPIMessage       $message smime message
+     *
+     * @access public
+     * @return void
+     */
+    public static function ParseSmime($session, $store, $addressBook, &$mapimessage) {
+        $props = mapi_getprops($mapimessage, array(PR_MESSAGE_CLASS));
+
+        if (isset($props[PR_MESSAGE_CLASS]) && stripos($props[PR_MESSAGE_CLASS], 'IPM.Note.SMIME.MultipartSigned') !== false) {
+            // this is a signed message. decode it.
+            $attachTable = mapi_message_getattachmenttable($mapimessage);
+            $rows = mapi_table_queryallrows($attachTable, array(PR_ATTACH_MIME_TAG, PR_ATTACH_NUM));
+            $attnum = false;
+
+            foreach($rows as $row) {
+                if (isset($row[PR_ATTACH_MIME_TAG]) && $row[PR_ATTACH_MIME_TAG] == 'multipart/signed') {
+                    $attnum = $row[PR_ATTACH_NUM];
+                }
+            }
+
+            if ($attnum !== false) {
+                $att = mapi_message_openattach($mapimessage, $attnum);
+                $data = mapi_openproperty($att, PR_ATTACH_DATA_BIN);
+                mapi_message_deleteattach($mapimessage, $attnum);
+                mapi_inetmapi_imtomapi($session, $store, $addressBook, $mapimessage, $data, array("parse_smime_signed" => 1));
+                ZLog::Write(LOGLEVEL_DEBUG, "Convert a smime signed message to a normal message.");
+            }
+            mapi_setprops($mapimessage, array(PR_MESSAGE_CLASS => 'IPM.Note.SMIME.MultipartSigned'));
+        }
+        // TODO check if we need to do this for encrypted (and signed?) message as well
+    }
 }
 
 ?>
\ No newline at end of file
