@@ -6,7 +6,7 @@
 *
 * Created   :   18.08.2011
 *
-* Copyright 2007 - 2012 Zarafa Deutschland GmbH
+* Copyright 2007 - 2013 Zarafa Deutschland GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License, version 3,
@@ -228,6 +228,12 @@ class ChangesMemoryWrapper extends HierarchyCache implements IImportChanges, IEx
                     return false;
                 }
 
+                // check if the parent ID is known on the device
+                if (!isset($folder->parentid) || $folder->parentid != "0" &&  !$this->GetFolder($folder->parentid)) {
+                    ZLog::Write(LOGLEVEL_DEBUG, sprintf("ChangesMemoryWrapper->ImportFolderChange(): Change for folder '%s' will not be sent as parent folder is not set or not known on mobile.", $folder->displayname));
+                    return false;
+                }
+
                 // load this change into memory
                 $this->changes[] = array(self::CHANGE, $folder);
 
